@@ -80,14 +80,13 @@ class PatternsAnnotator(AnnotatorBase):
 
         mapping = frozenset(params.mapping.items())
         labels = list(params.mapping.keys())
-        registry = get_registry(mapping)
-
         for document in documents:
             # Retrieve nlp pipe
             lang = document_language(document, None)
             if lang is None or lang not in supported_languages:
                 raise AttributeError(f"Metadata language {lang} is required and must be in {SUPPORTED_LANGUAGES}")
             nlp = get_nlp(lang)
+            registry = get_registry(mapping, lang)
             analyzer = AnalyzerEngine(registry=registry,
                                       nlp_engine=LoadedSpacyNlpEngine(lang, nlp),
                                       default_score_threshold=0,
@@ -162,13 +161,13 @@ class LoadedSpacyNlpEngine(SpacyNlpEngine):
 
 
 @lru_cache(maxsize=None)
-def get_registry(mapping_items):
+def get_registry(mapping_items, lang):
     recognizers = []
     for pname, pvalue in mapping_items:
         pattern_definition = json.loads(pvalue)
         patterns = [Pattern.from_dict(pat) for pat in pattern_definition['patterns']]
         recognizer = PatternRecognizer(
-            supported_entity=pname, patterns=patterns, context=pattern_definition.get('context', None)
+            supported_entity=pname, supported_language=lang, patterns=patterns, context=pattern_definition.get('context', None)
         )
         recognizers.append(recognizer)
     registry = RecognizerRegistry(recognizers)
